@@ -23,7 +23,7 @@ class HashidsField(Field):
         min_length=None,
         **kwargs
     ):
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, editable=False, **kwargs)
         self.real_field_name = real_field_name
         self.hashids_instance = hashids_instance
         self.salt = salt
@@ -34,7 +34,7 @@ class HashidsField(Field):
         self.attname = name
         self.name = name
         self.model = cls
-        self.column = ""
+        self.column = None
 
         if self.verbose_name is None:
             self.verbose_name = self.name
@@ -72,7 +72,10 @@ class HashidsField(Field):
         return Hashids(salt=salt, min_length=min_length, alphabet=alphabet)
 
     def get_prep_value(self, value):
-        return self.hashids_instance.decode(value)[0]
+        try:
+            return self.hashids_instance.decode(value)[0]
+        except IndexError:
+            return ''
 
     def from_db_value(self, value, expression, connection, *args):
         return self.hashids_instance.encode(value)
@@ -92,12 +95,15 @@ class HashidsField(Field):
     def __get__(self, instance, name=None):
         if not instance:
             return self
-        real_value = getattr(instance, self.real_field_name)
+        real_value = getattr(instance, self.real_field_name, None)
+        # the instance is not saved yet?
+        if real_value is None:
+            return ""
         assert isinstance(real_value, int)
         return self.hashids_instance.encode(real_value)
 
     def __set__(self, instance, value):
-        raise AttributeError("HashidsField is read only")
+        pass
 
     @classmethod
     def get_lookups(cls):
